@@ -3,18 +3,21 @@ Main interface for apigateway service type definitions.
 
 Usage::
 
-    from mypy_boto3.apigateway.type_defs import ThrottleSettingsTypeDef
+    ```python
+    from mypy_boto3_apigateway.type_defs import AccessLogSettingsTypeDef
 
-    data: ThrottleSettingsTypeDef = {...}
+    data: AccessLogSettingsTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from datetime import datetime
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,89 +25,75 @@ else:
 
 
 __all__ = (
-    "ThrottleSettingsTypeDef",
-    "AccountTypeDef",
-    "ApiKeyIdsTypeDef",
+    "AccessLogSettingsTypeDef",
     "ApiKeyTypeDef",
-    "ApiKeysTypeDef",
     "ApiStageTypeDef",
     "AuthorizerTypeDef",
-    "AuthorizersTypeDef",
     "BasePathMappingTypeDef",
-    "BasePathMappingsTypeDef",
     "CanarySettingsTypeDef",
     "ClientCertificateTypeDef",
-    "ClientCertificatesTypeDef",
-    "DeploymentCanarySettingsTypeDef",
-    "MethodSnapshotTypeDef",
     "DeploymentTypeDef",
-    "DeploymentsTypeDef",
-    "DocumentationPartIdsTypeDef",
     "DocumentationPartLocationTypeDef",
     "DocumentationPartTypeDef",
-    "DocumentationPartsTypeDef",
     "DocumentationVersionTypeDef",
-    "DocumentationVersionsTypeDef",
-    "EndpointConfigurationTypeDef",
     "DomainNameTypeDef",
-    "DomainNamesTypeDef",
-    "ExportResponseTypeDef",
+    "EndpointConfigurationTypeDef",
     "GatewayResponseTypeDef",
-    "GatewayResponsesTypeDef",
     "IntegrationResponseTypeDef",
     "IntegrationTypeDef",
     "MethodResponseTypeDef",
+    "MethodSettingTypeDef",
+    "MethodSnapshotTypeDef",
     "MethodTypeDef",
     "ModelTypeDef",
+    "QuotaSettingsTypeDef",
+    "RequestValidatorTypeDef",
+    "ResourceTypeDef",
+    "RestApiTypeDef",
+    "SdkConfigurationPropertyTypeDef",
+    "SdkTypeTypeDef",
+    "StageTypeDef",
+    "ThrottleSettingsTypeDef",
+    "TlsConfigTypeDef",
+    "UsagePlanKeyTypeDef",
+    "UsagePlanTypeDef",
+    "VpcLinkTypeDef",
+    "AccountTypeDef",
+    "ApiKeyIdsTypeDef",
+    "ApiKeysTypeDef",
+    "AuthorizersTypeDef",
+    "BasePathMappingsTypeDef",
+    "ClientCertificatesTypeDef",
+    "DeploymentCanarySettingsTypeDef",
+    "DeploymentsTypeDef",
+    "DocumentationPartIdsTypeDef",
+    "DocumentationPartsTypeDef",
+    "DocumentationVersionsTypeDef",
+    "DomainNamesTypeDef",
+    "ExportResponseTypeDef",
+    "GatewayResponsesTypeDef",
     "ModelsTypeDef",
     "PaginatorConfigTypeDef",
     "PatchOperationTypeDef",
-    "QuotaSettingsTypeDef",
-    "RequestValidatorTypeDef",
     "RequestValidatorsTypeDef",
-    "ResourceTypeDef",
     "ResourcesTypeDef",
-    "RestApiTypeDef",
     "RestApisTypeDef",
     "SdkResponseTypeDef",
-    "SdkConfigurationPropertyTypeDef",
-    "SdkTypeTypeDef",
     "SdkTypesTypeDef",
     "StageKeyTypeDef",
-    "AccessLogSettingsTypeDef",
-    "MethodSettingTypeDef",
-    "StageTypeDef",
     "StagesTypeDef",
     "TagsTypeDef",
     "TemplateTypeDef",
     "TestInvokeAuthorizerResponseTypeDef",
     "TestInvokeMethodResponseTypeDef",
-    "UsagePlanKeyTypeDef",
     "UsagePlanKeysTypeDef",
-    "UsagePlanTypeDef",
     "UsagePlansTypeDef",
     "UsageTypeDef",
-    "VpcLinkTypeDef",
     "VpcLinksTypeDef",
 )
 
-ThrottleSettingsTypeDef = TypedDict(
-    "ThrottleSettingsTypeDef", {"burstLimit": int, "rateLimit": float}, total=False
-)
-
-AccountTypeDef = TypedDict(
-    "AccountTypeDef",
-    {
-        "cloudwatchRoleArn": str,
-        "throttleSettings": ThrottleSettingsTypeDef,
-        "features": List[str],
-        "apiKeyVersion": str,
-    },
-    total=False,
-)
-
-ApiKeyIdsTypeDef = TypedDict(
-    "ApiKeyIdsTypeDef", {"ids": List[str], "warnings": List[str]}, total=False
+AccessLogSettingsTypeDef = TypedDict(
+    "AccessLogSettingsTypeDef", {"format": str, "destinationArn": str}, total=False
 )
 
 ApiKeyTypeDef = TypedDict(
@@ -124,15 +113,9 @@ ApiKeyTypeDef = TypedDict(
     total=False,
 )
 
-ApiKeysTypeDef = TypedDict(
-    "ApiKeysTypeDef",
-    {"warnings": List[str], "position": str, "items": List[ApiKeyTypeDef]},
-    total=False,
-)
-
 ApiStageTypeDef = TypedDict(
     "ApiStageTypeDef",
-    {"apiId": str, "stage": str, "throttle": Dict[str, ThrottleSettingsTypeDef]},
+    {"apiId": str, "stage": str, "throttle": Dict[str, "ThrottleSettingsTypeDef"]},
     total=False,
 )
 
@@ -153,18 +136,10 @@ AuthorizerTypeDef = TypedDict(
     total=False,
 )
 
-AuthorizersTypeDef = TypedDict(
-    "AuthorizersTypeDef", {"position": str, "items": List[AuthorizerTypeDef]}, total=False
-)
-
 BasePathMappingTypeDef = TypedDict(
     "BasePathMappingTypeDef", {"basePath": str, "restApiId": str, "stage": str}, total=False
 )
 
-BasePathMappingsTypeDef = TypedDict(
-    "BasePathMappingsTypeDef", {"position": str, "items": List[BasePathMappingTypeDef]}, total=False
-)
-
 CanarySettingsTypeDef = TypedDict(
     "CanarySettingsTypeDef",
     {
@@ -189,41 +164,17 @@ ClientCertificateTypeDef = TypedDict(
     total=False,
 )
 
-ClientCertificatesTypeDef = TypedDict(
-    "ClientCertificatesTypeDef",
-    {"position": str, "items": List[ClientCertificateTypeDef]},
-    total=False,
-)
-
-DeploymentCanarySettingsTypeDef = TypedDict(
-    "DeploymentCanarySettingsTypeDef",
-    {"percentTraffic": float, "stageVariableOverrides": Dict[str, str], "useStageCache": bool},
-    total=False,
-)
-
-MethodSnapshotTypeDef = TypedDict(
-    "MethodSnapshotTypeDef", {"authorizationType": str, "apiKeyRequired": bool}, total=False
-)
-
 DeploymentTypeDef = TypedDict(
     "DeploymentTypeDef",
     {
         "id": str,
         "description": str,
         "createdDate": datetime,
-        "apiSummary": Dict[str, Dict[str, MethodSnapshotTypeDef]],
+        "apiSummary": Dict[str, Dict[str, "MethodSnapshotTypeDef"]],
     },
     total=False,
 )
 
-DeploymentsTypeDef = TypedDict(
-    "DeploymentsTypeDef", {"position": str, "items": List[DeploymentTypeDef]}, total=False
-)
-
-DocumentationPartIdsTypeDef = TypedDict(
-    "DocumentationPartIdsTypeDef", {"ids": List[str], "warnings": List[str]}, total=False
-)
-
 _RequiredDocumentationPartLocationTypeDef = TypedDict(
     "_RequiredDocumentationPartLocationTypeDef",
     {
@@ -258,13 +209,7 @@ class DocumentationPartLocationTypeDef(
 
 DocumentationPartTypeDef = TypedDict(
     "DocumentationPartTypeDef",
-    {"id": str, "location": DocumentationPartLocationTypeDef, "properties": str},
-    total=False,
-)
-
-DocumentationPartsTypeDef = TypedDict(
-    "DocumentationPartsTypeDef",
-    {"position": str, "items": List[DocumentationPartTypeDef]},
+    {"id": str, "location": "DocumentationPartLocationTypeDef", "properties": str},
     total=False,
 )
 
@@ -274,18 +219,6 @@ DocumentationVersionTypeDef = TypedDict(
     total=False,
 )
 
-DocumentationVersionsTypeDef = TypedDict(
-    "DocumentationVersionsTypeDef",
-    {"position": str, "items": List[DocumentationVersionTypeDef]},
-    total=False,
-)
-
-EndpointConfigurationTypeDef = TypedDict(
-    "EndpointConfigurationTypeDef",
-    {"types": List[Literal["REGIONAL", "EDGE", "PRIVATE"]], "vpcEndpointIds": List[str]},
-    total=False,
-)
-
 DomainNameTypeDef = TypedDict(
     "DomainNameTypeDef",
     {
@@ -299,7 +232,7 @@ DomainNameTypeDef = TypedDict(
         "regionalCertificateArn": str,
         "distributionDomainName": str,
         "distributionHostedZoneId": str,
-        "endpointConfiguration": EndpointConfigurationTypeDef,
+        "endpointConfiguration": "EndpointConfigurationTypeDef",
         "domainNameStatus": Literal["AVAILABLE", "UPDATING", "PENDING"],
         "domainNameStatusMessage": str,
         "securityPolicy": Literal["TLS_1_0", "TLS_1_2"],
@@ -308,13 +241,9 @@ DomainNameTypeDef = TypedDict(
     total=False,
 )
 
-DomainNamesTypeDef = TypedDict(
-    "DomainNamesTypeDef", {"position": str, "items": List[DomainNameTypeDef]}, total=False
-)
-
-ExportResponseTypeDef = TypedDict(
-    "ExportResponseTypeDef",
-    {"contentType": str, "contentDisposition": str, "body": Union[bytes, IO]},
+EndpointConfigurationTypeDef = TypedDict(
+    "EndpointConfigurationTypeDef",
+    {"types": List[Literal["REGIONAL", "EDGE", "PRIVATE"]], "vpcEndpointIds": List[str]},
     total=False,
 )
 
@@ -351,10 +280,6 @@ GatewayResponseTypeDef = TypedDict(
     total=False,
 )
 
-GatewayResponsesTypeDef = TypedDict(
-    "GatewayResponsesTypeDef", {"position": str, "items": List[GatewayResponseTypeDef]}, total=False
-)
-
 IntegrationResponseTypeDef = TypedDict(
     "IntegrationResponseTypeDef",
     {
@@ -383,7 +308,8 @@ IntegrationTypeDef = TypedDict(
         "timeoutInMillis": int,
         "cacheNamespace": str,
         "cacheKeyParameters": List[str],
-        "integrationResponses": Dict[str, IntegrationResponseTypeDef],
+        "integrationResponses": Dict[str, "IntegrationResponseTypeDef"],
+        "tlsConfig": "TlsConfigTypeDef",
     },
     total=False,
 )
@@ -394,139 +320,6 @@ MethodResponseTypeDef = TypedDict(
     total=False,
 )
 
-MethodTypeDef = TypedDict(
-    "MethodTypeDef",
-    {
-        "httpMethod": str,
-        "authorizationType": str,
-        "authorizerId": str,
-        "apiKeyRequired": bool,
-        "requestValidatorId": str,
-        "operationName": str,
-        "requestParameters": Dict[str, bool],
-        "requestModels": Dict[str, str],
-        "methodResponses": Dict[str, MethodResponseTypeDef],
-        "methodIntegration": IntegrationTypeDef,
-        "authorizationScopes": List[str],
-    },
-    total=False,
-)
-
-ModelTypeDef = TypedDict(
-    "ModelTypeDef",
-    {"id": str, "name": str, "description": str, "schema": str, "contentType": str},
-    total=False,
-)
-
-ModelsTypeDef = TypedDict(
-    "ModelsTypeDef", {"position": str, "items": List[ModelTypeDef]}, total=False
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
-)
-
-PatchOperationTypeDef = TypedDict(
-    "PatchOperationTypeDef",
-    {
-        "op": Literal["add", "remove", "replace", "move", "copy", "test"],
-        "path": str,
-        "value": str,
-        "from": str,
-    },
-    total=False,
-)
-
-QuotaSettingsTypeDef = TypedDict(
-    "QuotaSettingsTypeDef",
-    {"limit": int, "offset": int, "period": Literal["DAY", "WEEK", "MONTH"]},
-    total=False,
-)
-
-RequestValidatorTypeDef = TypedDict(
-    "RequestValidatorTypeDef",
-    {"id": str, "name": str, "validateRequestBody": bool, "validateRequestParameters": bool},
-    total=False,
-)
-
-RequestValidatorsTypeDef = TypedDict(
-    "RequestValidatorsTypeDef",
-    {"position": str, "items": List[RequestValidatorTypeDef]},
-    total=False,
-)
-
-ResourceTypeDef = TypedDict(
-    "ResourceTypeDef",
-    {
-        "id": str,
-        "parentId": str,
-        "pathPart": str,
-        "path": str,
-        "resourceMethods": Dict[str, MethodTypeDef],
-    },
-    total=False,
-)
-
-ResourcesTypeDef = TypedDict(
-    "ResourcesTypeDef", {"position": str, "items": List[ResourceTypeDef]}, total=False
-)
-
-RestApiTypeDef = TypedDict(
-    "RestApiTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "description": str,
-        "createdDate": datetime,
-        "version": str,
-        "warnings": List[str],
-        "binaryMediaTypes": List[str],
-        "minimumCompressionSize": int,
-        "apiKeySource": Literal["HEADER", "AUTHORIZER"],
-        "endpointConfiguration": EndpointConfigurationTypeDef,
-        "policy": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-RestApisTypeDef = TypedDict(
-    "RestApisTypeDef", {"position": str, "items": List[RestApiTypeDef]}, total=False
-)
-
-SdkResponseTypeDef = TypedDict(
-    "SdkResponseTypeDef",
-    {"contentType": str, "contentDisposition": str, "body": Union[bytes, IO]},
-    total=False,
-)
-
-SdkConfigurationPropertyTypeDef = TypedDict(
-    "SdkConfigurationPropertyTypeDef",
-    {"name": str, "friendlyName": str, "description": str, "required": bool, "defaultValue": str},
-    total=False,
-)
-
-SdkTypeTypeDef = TypedDict(
-    "SdkTypeTypeDef",
-    {
-        "id": str,
-        "friendlyName": str,
-        "description": str,
-        "configurationProperties": List[SdkConfigurationPropertyTypeDef],
-    },
-    total=False,
-)
-
-SdkTypesTypeDef = TypedDict(
-    "SdkTypesTypeDef", {"position": str, "items": List[SdkTypeTypeDef]}, total=False
-)
-
-StageKeyTypeDef = TypedDict("StageKeyTypeDef", {"restApiId": str, "stageName": str}, total=False)
-
-AccessLogSettingsTypeDef = TypedDict(
-    "AccessLogSettingsTypeDef", {"format": str, "destinationArn": str}, total=False
-)
-
 MethodSettingTypeDef = TypedDict(
     "MethodSettingTypeDef",
     {
@@ -546,6 +339,94 @@ MethodSettingTypeDef = TypedDict(
     total=False,
 )
 
+MethodSnapshotTypeDef = TypedDict(
+    "MethodSnapshotTypeDef", {"authorizationType": str, "apiKeyRequired": bool}, total=False
+)
+
+MethodTypeDef = TypedDict(
+    "MethodTypeDef",
+    {
+        "httpMethod": str,
+        "authorizationType": str,
+        "authorizerId": str,
+        "apiKeyRequired": bool,
+        "requestValidatorId": str,
+        "operationName": str,
+        "requestParameters": Dict[str, bool],
+        "requestModels": Dict[str, str],
+        "methodResponses": Dict[str, "MethodResponseTypeDef"],
+        "methodIntegration": "IntegrationTypeDef",
+        "authorizationScopes": List[str],
+    },
+    total=False,
+)
+
+ModelTypeDef = TypedDict(
+    "ModelTypeDef",
+    {"id": str, "name": str, "description": str, "schema": str, "contentType": str},
+    total=False,
+)
+
+QuotaSettingsTypeDef = TypedDict(
+    "QuotaSettingsTypeDef",
+    {"limit": int, "offset": int, "period": Literal["DAY", "WEEK", "MONTH"]},
+    total=False,
+)
+
+RequestValidatorTypeDef = TypedDict(
+    "RequestValidatorTypeDef",
+    {"id": str, "name": str, "validateRequestBody": bool, "validateRequestParameters": bool},
+    total=False,
+)
+
+ResourceTypeDef = TypedDict(
+    "ResourceTypeDef",
+    {
+        "id": str,
+        "parentId": str,
+        "pathPart": str,
+        "path": str,
+        "resourceMethods": Dict[str, "MethodTypeDef"],
+    },
+    total=False,
+)
+
+RestApiTypeDef = TypedDict(
+    "RestApiTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "description": str,
+        "createdDate": datetime,
+        "version": str,
+        "warnings": List[str],
+        "binaryMediaTypes": List[str],
+        "minimumCompressionSize": int,
+        "apiKeySource": Literal["HEADER", "AUTHORIZER"],
+        "endpointConfiguration": "EndpointConfigurationTypeDef",
+        "policy": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+SdkConfigurationPropertyTypeDef = TypedDict(
+    "SdkConfigurationPropertyTypeDef",
+    {"name": str, "friendlyName": str, "description": str, "required": bool, "defaultValue": str},
+    total=False,
+)
+
+SdkTypeTypeDef = TypedDict(
+    "SdkTypeTypeDef",
+    {
+        "id": str,
+        "friendlyName": str,
+        "description": str,
+        "configurationProperties": List["SdkConfigurationPropertyTypeDef"],
+    },
+    total=False,
+)
+
 StageTypeDef = TypedDict(
     "StageTypeDef",
     {
@@ -562,11 +443,11 @@ StageTypeDef = TypedDict(
             "NOT_AVAILABLE",
             "FLUSH_IN_PROGRESS",
         ],
-        "methodSettings": Dict[str, MethodSettingTypeDef],
+        "methodSettings": Dict[str, "MethodSettingTypeDef"],
         "variables": Dict[str, str],
         "documentationVersion": str,
-        "accessLogSettings": AccessLogSettingsTypeDef,
-        "canarySettings": CanarySettingsTypeDef,
+        "accessLogSettings": "AccessLogSettingsTypeDef",
+        "canarySettings": "CanarySettingsTypeDef",
         "tracingEnabled": bool,
         "webAclArn": str,
         "tags": Dict[str, str],
@@ -576,7 +457,170 @@ StageTypeDef = TypedDict(
     total=False,
 )
 
-StagesTypeDef = TypedDict("StagesTypeDef", {"item": List[StageTypeDef]}, total=False)
+ThrottleSettingsTypeDef = TypedDict(
+    "ThrottleSettingsTypeDef", {"burstLimit": int, "rateLimit": float}, total=False
+)
+
+TlsConfigTypeDef = TypedDict("TlsConfigTypeDef", {"insecureSkipVerification": bool}, total=False)
+
+UsagePlanKeyTypeDef = TypedDict(
+    "UsagePlanKeyTypeDef", {"id": str, "type": str, "value": str, "name": str}, total=False
+)
+
+UsagePlanTypeDef = TypedDict(
+    "UsagePlanTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "description": str,
+        "apiStages": List["ApiStageTypeDef"],
+        "throttle": "ThrottleSettingsTypeDef",
+        "quota": "QuotaSettingsTypeDef",
+        "productCode": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+VpcLinkTypeDef = TypedDict(
+    "VpcLinkTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "description": str,
+        "targetArns": List[str],
+        "status": Literal["AVAILABLE", "PENDING", "DELETING", "FAILED"],
+        "statusMessage": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+AccountTypeDef = TypedDict(
+    "AccountTypeDef",
+    {
+        "cloudwatchRoleArn": str,
+        "throttleSettings": "ThrottleSettingsTypeDef",
+        "features": List[str],
+        "apiKeyVersion": str,
+    },
+    total=False,
+)
+
+ApiKeyIdsTypeDef = TypedDict(
+    "ApiKeyIdsTypeDef", {"ids": List[str], "warnings": List[str]}, total=False
+)
+
+ApiKeysTypeDef = TypedDict(
+    "ApiKeysTypeDef",
+    {"warnings": List[str], "position": str, "items": List["ApiKeyTypeDef"]},
+    total=False,
+)
+
+AuthorizersTypeDef = TypedDict(
+    "AuthorizersTypeDef", {"position": str, "items": List["AuthorizerTypeDef"]}, total=False
+)
+
+BasePathMappingsTypeDef = TypedDict(
+    "BasePathMappingsTypeDef",
+    {"position": str, "items": List["BasePathMappingTypeDef"]},
+    total=False,
+)
+
+ClientCertificatesTypeDef = TypedDict(
+    "ClientCertificatesTypeDef",
+    {"position": str, "items": List["ClientCertificateTypeDef"]},
+    total=False,
+)
+
+DeploymentCanarySettingsTypeDef = TypedDict(
+    "DeploymentCanarySettingsTypeDef",
+    {"percentTraffic": float, "stageVariableOverrides": Dict[str, str], "useStageCache": bool},
+    total=False,
+)
+
+DeploymentsTypeDef = TypedDict(
+    "DeploymentsTypeDef", {"position": str, "items": List["DeploymentTypeDef"]}, total=False
+)
+
+DocumentationPartIdsTypeDef = TypedDict(
+    "DocumentationPartIdsTypeDef", {"ids": List[str], "warnings": List[str]}, total=False
+)
+
+DocumentationPartsTypeDef = TypedDict(
+    "DocumentationPartsTypeDef",
+    {"position": str, "items": List["DocumentationPartTypeDef"]},
+    total=False,
+)
+
+DocumentationVersionsTypeDef = TypedDict(
+    "DocumentationVersionsTypeDef",
+    {"position": str, "items": List["DocumentationVersionTypeDef"]},
+    total=False,
+)
+
+DomainNamesTypeDef = TypedDict(
+    "DomainNamesTypeDef", {"position": str, "items": List["DomainNameTypeDef"]}, total=False
+)
+
+ExportResponseTypeDef = TypedDict(
+    "ExportResponseTypeDef",
+    {"contentType": str, "contentDisposition": str, "body": bytes},
+    total=False,
+)
+
+GatewayResponsesTypeDef = TypedDict(
+    "GatewayResponsesTypeDef",
+    {"position": str, "items": List["GatewayResponseTypeDef"]},
+    total=False,
+)
+
+ModelsTypeDef = TypedDict(
+    "ModelsTypeDef", {"position": str, "items": List["ModelTypeDef"]}, total=False
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+)
+
+PatchOperationTypeDef = TypedDict(
+    "PatchOperationTypeDef",
+    {
+        "op": Literal["add", "remove", "replace", "move", "copy", "test"],
+        "path": str,
+        "value": str,
+        "from": str,
+    },
+    total=False,
+)
+
+RequestValidatorsTypeDef = TypedDict(
+    "RequestValidatorsTypeDef",
+    {"position": str, "items": List["RequestValidatorTypeDef"]},
+    total=False,
+)
+
+ResourcesTypeDef = TypedDict(
+    "ResourcesTypeDef", {"position": str, "items": List["ResourceTypeDef"]}, total=False
+)
+
+RestApisTypeDef = TypedDict(
+    "RestApisTypeDef", {"position": str, "items": List["RestApiTypeDef"]}, total=False
+)
+
+SdkResponseTypeDef = TypedDict(
+    "SdkResponseTypeDef",
+    {"contentType": str, "contentDisposition": str, "body": bytes},
+    total=False,
+)
+
+SdkTypesTypeDef = TypedDict(
+    "SdkTypesTypeDef", {"position": str, "items": List["SdkTypeTypeDef"]}, total=False
+)
+
+StageKeyTypeDef = TypedDict("StageKeyTypeDef", {"restApiId": str, "stageName": str}, total=False)
+
+StagesTypeDef = TypedDict("StagesTypeDef", {"item": List["StageTypeDef"]}, total=False)
 
 TagsTypeDef = TypedDict("TagsTypeDef", {"tags": Dict[str, str]}, total=False)
 
@@ -609,31 +653,12 @@ TestInvokeMethodResponseTypeDef = TypedDict(
     total=False,
 )
 
-UsagePlanKeyTypeDef = TypedDict(
-    "UsagePlanKeyTypeDef", {"id": str, "type": str, "value": str, "name": str}, total=False
-)
-
 UsagePlanKeysTypeDef = TypedDict(
-    "UsagePlanKeysTypeDef", {"position": str, "items": List[UsagePlanKeyTypeDef]}, total=False
-)
-
-UsagePlanTypeDef = TypedDict(
-    "UsagePlanTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "description": str,
-        "apiStages": List[ApiStageTypeDef],
-        "throttle": ThrottleSettingsTypeDef,
-        "quota": QuotaSettingsTypeDef,
-        "productCode": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
+    "UsagePlanKeysTypeDef", {"position": str, "items": List["UsagePlanKeyTypeDef"]}, total=False
 )
 
 UsagePlansTypeDef = TypedDict(
-    "UsagePlansTypeDef", {"position": str, "items": List[UsagePlanTypeDef]}, total=False
+    "UsagePlansTypeDef", {"position": str, "items": List["UsagePlanTypeDef"]}, total=False
 )
 
 UsageTypeDef = TypedDict(
@@ -648,20 +673,6 @@ UsageTypeDef = TypedDict(
     total=False,
 )
 
-VpcLinkTypeDef = TypedDict(
-    "VpcLinkTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "description": str,
-        "targetArns": List[str],
-        "status": Literal["AVAILABLE", "PENDING", "DELETING", "FAILED"],
-        "statusMessage": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 VpcLinksTypeDef = TypedDict(
-    "VpcLinksTypeDef", {"position": str, "items": List[VpcLinkTypeDef]}, total=False
+    "VpcLinksTypeDef", {"position": str, "items": List["VpcLinkTypeDef"]}, total=False
 )
